Module encode

Module encode 

Various types associated with encoding stream data from sound banks.

Structs

PcmError
Represents an error that can occur when encoding a PCM stream.
VorbisError
Represents an error that can occur when encoding a Vorbis stream.

Enums

EncodeError
Represents an error that can occur when encoding a sound bank stream.
PcmErrorKind
A variant of a PcmError.
VorbisErrorKind
A variant of a VorbisError.